==> rsgislib-3.4.9.tar.gz: rsgislib-3.4.9/src/cmds/RSGISCmdException.h <==
/*
 *  RSGISCmdException.h
 *
 *  Created by Pete Bunting on 29/04/2013.
 *  Copyright 2013 RSGISLib.
 *
 *  RSGISLib is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  RSGISLib is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with RSGISLib.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef RSGISCmdException_H
#define RSGISCmdException_H

#include <exception>
#include <iostream>
#include <string>

#include "RSGISCmdCommon.h"

// mark all exported classes/functions with DllExport to have
// them exported by Visual Studio
#undef DllExport
#ifdef _MSC_VER
    #ifdef rsgis_cmds_EXPORTS
        #define DllExport   __declspec( dllexport )
    #else
        #define DllExport   __declspec( dllimport )
    #endif
#else
    #define DllExport
#endif

namespace rsgis{ namespace cmds {

	class DllExport RSGISCmdException : public std::exception
	{
    public:
        RSGISCmdException();
        RSGISCmdException(const char *message);
        RSGISCmdException(std::string message);
        virtual ~RSGISCmdException() throw();
        virtual const char* what() const throw();
    protected:
        std::string msgs;
	};
}}


#endif

==> rsgislib-5.2.1.tar.gz: rsgislib-5.2.1/src/cmds/RSGISCmdException.h <==
/*
 *  RSGISCmdException.h
 *
 *  Created by Pete Bunting on 29/04/2013.
 *  Copyright 2013 RSGISLib.
 *
 *  RSGISLib is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  RSGISLib is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with RSGISLib.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef RSGISCmdException_H
#define RSGISCmdException_H

#include <exception>
#include <iostream>
#include <string>

#include "RSGISCmdCommon.h"

// mark all exported classes/functions with DllExport to have
// them exported by Visual Studio
#undef DllExport
#ifdef _MSC_VER
    #ifdef rsgis_cmds_EXPORTS
        #define DllExport   __declspec( dllexport )
    #else
        #define DllExport   __declspec( dllimport )
    #endif
#else
    #define DllExport
#endif

namespace rsgis{ namespace cmds {

	class DllExport RSGISCmdException : public std::exception
	{
    public:
        RSGISCmdException();
        RSGISCmdException(const char *message);
        RSGISCmdException(std::string message);
        virtual ~RSGISCmdException();
        virtual const char* what() const noexcept;
    protected:
        std::string msgs;
	};
}}


#endif
